@@ -162,9 +162,9 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_getDTD, 5),
 	ENTRY(RS_XML_libxmlVersion, 0),
 	ENTRY(RS_XML_Parse, 17),
-	ENTRY(RS_XML_ParseTree, 19),
+	ENTRY(RS_XML_ParseTree, 20),
 	ENTRY(R_newXMLDtd, 5),
-	ENTRY(R_newXMLDoc, 2),
+	ENTRY(R_newXMLDoc, 3),
 	ENTRY(R_newXMLNode, 6),
 	ENTRY(R_newXMLTextNode, 3),
 	ENTRY(R_xmlNewComment, 3),
@@ -178,7 +178,7 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(R_xmlCatalogResolve, 3),
 	ENTRY(RS_XML_xmlNodeNumChildren, 1),
         ENTRY(RS_XML_unsetDoc, 4),
-        ENTRY(RS_XML_printXMLNode, 5),
+        ENTRY(RS_XML_printXMLNode, 6),
         ENTRY(RS_XML_dumpHTMLDoc, 5),
         ENTRY(RS_XML_removeChildren, 3),
         ENTRY(RS_XML_clone, 3),
@@ -244,6 +244,7 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_getDefaultValiditySetting, 1),
 	ENTRY(RS_XML_xmlXIncludeProcessFlags, 2),
 	ENTRY(RS_XML_xmlXIncludeProcessTreeFlags, 2),
+	ENTRY(R_convertXMLNsRef, 1),
 	{NULL, NULL, 0}
 };
 
@@ -346,7 +347,7 @@ CreateCharSexpWithEncoding(const xmlChar *encoding, const xmlChar *str)
     else {
 	str = translateChar(mkChar(str));
     }
-
+// REprintf("encoding: %d\n", enc);
     ans = mkCharCE(str, enc);
 #else
     ans = mkChar(str);
