@@ -32,6 +32,7 @@
 #else
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
+#include <libxml/HTMLtree.h>
 #endif
 
 
@@ -725,17 +726,26 @@ R_xmlRootNode(USER_OBJECT_ sdoc, USER_OBJECT_ skipDtd, USER_OBJECT_ manageMemory
 /**
  Create an S object representing a newly created internal 
  XML document object.
-
  */
 
 int R_numXMLDocs = 0;
 int R_numXMLDocsFreed = 0;
 
 USER_OBJECT_
-R_newXMLDoc(USER_OBJECT_ dtd, USER_OBJECT_ namespaces)
+R_newXMLDoc(USER_OBJECT_ dtd, USER_OBJECT_ namespaces, USER_OBJECT_ isHTML)
 {
   xmlDocPtr doc;
-  doc = xmlNewDoc(CHAR_TO_XMLCHAR("1.0"));
+  if(LOGICAL(isHTML)[0]) {
+      const char *d = (TYPEOF(dtd) == STRSXP && Rf_length(dtd)) ? 
+                                CHAR_DEREF(STRING_ELT(dtd, 0)) : NULL;
+      if(d[0] == '5')
+	  doc = htmlNewDoc("", NULL);
+      else
+	  doc = htmlNewDocNoDtD(d && d[0] ? CHAR_TO_XMLCHAR(d) : NULL, NULL);
+
+  } else
+      doc = xmlNewDoc(CHAR_TO_XMLCHAR("1.0"));
+
   R_numXMLDocs++;
 
   return(R_createXMLDocRef(doc));
@@ -899,7 +909,7 @@ R_createXMLDocRef(xmlDocPtr doc)
 
   PROTECT(ref = R_MakeExternalPtr(doc, Rf_install("XMLInternalDocument"), R_NilValue));
   PROTECT(tmp = NEW_CHARACTER(1));
-  SET_STRING_ELT(tmp, 0, mkChar("XMLInternalDocument"));
+  SET_STRING_ELT(tmp, 0, mkChar( doc->type == XML_HTML_DOCUMENT_NODE ? "HTMLInternalDocument" : "XMLInternalDocument"));
   SET_CLASS(ref, tmp);
   UNPROTECT(2);
   return(ref);
@@ -1703,3 +1713,59 @@ R_getChildByName(USER_OBJECT_ r_node, USER_OBJECT_ r_index, USER_OBJECT_ r_addFi
 
     return(R_createXMLNodeRef(ptr, r_addFinalizer));
 }
+
+
+/*
+ This is a C-level version equivalent to
+     xmlApply(node, xmlValue)
+
+ 
+*/
+
+USER_OBJECT_
+R_childStringValues(SEXP r_node, SEXP r_len, SEXP r_asVector, SEXP r_encoding, SEXP r_addNames)
+{
+    xmlNodePtr node, kid;
+    int len, i;
+    SEXP ans, names = NULL;
+    int asVector = LOGICAL(r_asVector)[0];
+    int encoding = INTEGER(r_encoding)[0];
+    xmlChar *tmp;
+    int nprotect = 0;
+
+    node = (xmlNodePtr) R_ExternalPtrAddr(r_node);    
+    len = INTEGER(r_len)[0];
+
+    if(asVector)
+	ans = NEW_CHARACTER(len);
+    else
+	ans = NEW_LIST(len);
+
+    PROTECT(ans); nprotect++;
+
+    if(LOGICAL(r_addNames)[0]) {
+	PROTECT(names = NEW_CHARACTER(len));
+	nprotect++;
+    }
+
+
+    for(i = 0, kid = node->children; kid && i < len; i++, kid = kid->next) {
+	tmp  = xmlNodeGetContent(kid);	
+	SEXP val = mkCharCE(tmp, encoding);
+	PROTECT(val);
+	if(asVector)
+	    SET_STRING_ELT(ans, i, val);
+	else
+	    SET_VECTOR_ELT(ans, i, ScalarString(val));
+	if(names && kid->name) {
+	    SET_STRING_ELT(names, i, mkCharCE(kid->name, encoding));
+	}
+	UNPROTECT(1);
+    }
+
+    if(names)
+	SET_NAMES(ans, names);
+
+    UNPROTECT(nprotect);
+    return(ans);
+}
